QR: Wind power scenarios generated by Quantile Regression with Gaussian copula approach
Description
This data set provides 24-hour wind power scenarios and observations for 345 instances (days)
Usage
data("QR")
Arguments
Format
A list containing wind power scenarios for 345 days, where each day includes 27 scenarios and one observation of dimension 24, representing hourly values.
References
[2]D. Sari, S.Ryan. Reliability of wind power scenarios and stochastic unit commitment cost. Under review.